package App::httpstatus::more;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2019-12-24'; # DATE
our $DIST = 'App-httpstatus-more'; # DIST
our $VERSION = '2.0.0.1'; # VERSION

1;
# ABSTRACT: Display HTTP status code information

__END__

=pod

=encoding UTF-8

=head1 NAME

App::httpstatus::more - Display HTTP status code information

=head1 VERSION

version 2.0.0.1

=head1 SYNOPSIS

See L<httpstatus> script.

=head1 DESCRIPTION

This is a fork of L<App::httpstatus> 2.0.0 to add more codes. The original
script has not been updated since 2013.

=head1 SEE ALSO

L<App::httpstatus>, the original script.

=head1 ORIGINAL AUTHOR

Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>

=head1 ORIGINAL LICENSE

Copyright (C) Tokuhiro Matsuno

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
